==> kdepim-addons-17.04.3.tar.xz: kdepim-addons-17.04.3/kmail/plugins/logactivitiesplugin/logactivitiesplugin.cpp <==
/*
   Copyright (C) 2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "logactivitiesplugin.h"
#include "logactivitiesplugininterface.h"
#include <kpluginfactory.h>

K_PLUGIN_FACTORY_WITH_JSON(KMailAntiSpamPluginFactory, "kmail_logactivitiesplugin.json", registerPlugin<LogActivitiesPlugin>();)

LogActivitiesPlugin::LogActivitiesPlugin(QObject *parent, const QList<QVariant> &)
    : PimCommon::GenericPlugin(parent)
{

}

LogActivitiesPlugin::~LogActivitiesPlugin()
{

}

PimCommon::GenericPluginInterface *LogActivitiesPlugin::createInterface(KActionCollection *ac, QObject *parent)
{
    LogActivitiesPluginInterface *interface = new LogActivitiesPluginInterface(parent);
    interface->createAction(ac);
    return interface;
}

#include "logactivitiesplugin.moc"

==> kdepim-addons_17.12.3.orig.tar.xz: kdepim-addons-17.12.3/kmail/plugins/logactivitiesplugin/logactivitiesplugin.cpp <==
/*
   Copyright (C) 2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "logactivitiesplugin.h"
#include "logactivitiesplugininterface.h"
#include <kpluginfactory.h>

K_PLUGIN_FACTORY_WITH_JSON(KMailAntiSpamPluginFactory, "kmail_logactivitiesplugin.json", registerPlugin<LogActivitiesPlugin>();
                           )

LogActivitiesPlugin::LogActivitiesPlugin(QObject *parent, const QList<QVariant> &)
    : PimCommon::GenericPlugin(parent)
{
}

LogActivitiesPlugin::~LogActivitiesPlugin()
{
}

PimCommon::GenericPluginInterface *LogActivitiesPlugin::createInterface(KActionCollection *ac, QObject *parent)
{
    LogActivitiesPluginInterface *interface = new LogActivitiesPluginInterface(parent);
    interface->createAction(ac);
    return interface;
}

#include "logactivitiesplugin.moc"
